@@ -55,7 +55,9 @@ int main(int argc, char *argv[])
 {
     global_debug = 0;
     // Fixes blurry icons with fractional scaling
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication application(argc, argv);
     KLocalizedString::setApplicationDomain("lskat");
 
@@ -65,7 +67,7 @@ int main(int argc, char *argv[])
                           KAboutLicense::GPL,
                           i18n("(c) 1995-2007, Martin Heni"),
                           QString(),
-                          QStringLiteral("https://games.kde.org/games/lskat"));
+                          QStringLiteral("https://apps.kde.org/lskat"));
 
     // I18N: These are the same strings as in kwin4, you can copy the translations
     aboutData.addAuthor(i18n("Martin Heni"), i18n("Game design and code"), QStringLiteral("kde@heni-online.de"));
